@@ -5,7 +5,11 @@ from django.conf import settings
 # VIEW CONSTS
 
 LIST_VIEW = """
-
+@swagger_auto_schema(method='get', responses={200: 'done'})
+@api_view(['GET'])
+@never_cache
+@renderer_classes([SwaggerUIRenderer, OpenAPIRenderer])
+@permission_classes((AllowAny, IsAuthenticated))
 def %(lower_model)s_list(request):
 
     %(lower_model) =  %(model)s.objects.all()
@@ -256,7 +260,7 @@ class Scaffold(object):
         need_import_users = True
         need_import_token = True
         need_import_JsonResponse = True
-        need_import_all = True
+        # need_import_all = True
 
         for line in import_file.readlines():
             if 'from django.shortcuts import render, redirect, get_object_or_404' in line:
@@ -269,18 +273,18 @@ class Scaffold(object):
                 need_import_token = False
             if 'from django3scaffold.http import JsonResponse' in line:
                 need_import_JsonResponse = False
-            if """import json
-from drf_yasg import openapi
-from django.core import serializers
-from django.http import JsonResponse
-from drf_yasg.utils import swagger_auto_schema
-from rest_framework.permissions import AllowAny
-from django.views.decorators.cache import never_cache
-from rest_framework.permissions import IsAuthenticated
-from rest_framework.decorators import permission_classes
-from rest_framework.decorators import api_view, renderer_classes
-from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer""" in line:
-                need_import_all = False
+#             if """import json
+# from drf_yasg import openapi
+# from django.core import serializers
+# from django.http import JsonResponse
+# from drf_yasg.utils import swagger_auto_schema
+# from rest_framework.permissions import AllowAny
+# from django.views.decorators.cache import never_cache
+# from rest_framework.permissions import IsAuthenticated
+# from rest_framework.decorators import permission_classes
+# from rest_framework.decorators import api_view, renderer_classes
+# from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer""" in line:
+#                 need_import_all = False
 
         if need_import_shortcut:
             import_list.append('from django.shortcuts import render, redirect, get_object_or_404')
@@ -414,6 +418,9 @@ from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer""" in line:
         lower_model = self.model.lower()
 
         # Check if view already exists
+        print(LIST_VIEW)
+        print(LIST_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
+    
         if not self.view_exists(view_path, "%s_list" % lower_model):
             view_list.append(LIST_VIEW % {'lower_model': lower_model, 'model': self.model})
             self._info("added \t%s\t%s_view" % (view_path, lower_model), 1)
